==> egov-common-1.0.6-sources.jar: com/gtis/plat/vo/PfTaskVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfTaskVo implements Serializable {

    private String taskId;

    private String activityId;

    private boolean accepted;

    private PfUserVo userVo;

    private String remark;

    private boolean agree;

    private String performerId;

    private boolean backState;

    private String taskBefore = "";
    private Date beginTime;
    private Date finishTime;

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public boolean isBackState() {
        return backState;
    }

    public void setBackState(boolean backState) {
        this.backState = backState;
    }

    public String getTaskBefore() {
        return taskBefore;
    }

    public void setTaskBefore(String taskBefore) {
        this.taskBefore = taskBefore;
    }

    public String getPerformerId() {
        return performerId;
    }

    public void setPerformerId(String performerId) {
        this.performerId = performerId;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public boolean isAgree() {
        return agree;
    }

    public void setAgree(boolean agree) {
        this.agree = agree;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public boolean isAccepted() {
        return accepted;
    }

    public void setAccepted(boolean accepted) {
        this.accepted = accepted;
    }

    public PfUserVo getUserVo() {
        return userVo;
    }

    public void setUserVo(PfUserVo userVo) {
        this.userVo = userVo;
    }

}

==> egov-common-1.1.9-sources.jar: com/gtis/plat/vo/PfTaskVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfTaskVo implements Serializable {

    private String taskId;

    private String activityId;

    private boolean accepted;

    private PfUserVo userVo;

    private String remark;

    private boolean agree;

    private String performerId;

    private boolean backState;

    private String taskBefore = "";
    private Date beginTime;
    private Date finishTime;
    private boolean repeat;
    private Date overTime;    //任务截止时间

    public Date getOverTime() {
        return overTime;
    }

    public void setOverTime(Date overTime) {
        this.overTime = overTime;
    }

    public boolean isRepeat() {
        return repeat;
    }

    public void setRepeat(boolean repeat) {
        this.repeat = repeat;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public boolean isBackState() {
        return backState;
    }

    public void setBackState(boolean backState) {
        this.backState = backState;
    }

    public String getTaskBefore() {
        return taskBefore;
    }

    public void setTaskBefore(String taskBefore) {
        this.taskBefore = taskBefore;
    }

    public String getPerformerId() {
        return performerId;
    }

    public void setPerformerId(String performerId) {
        this.performerId = performerId;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public boolean isAgree() {
        return agree;
    }

    public void setAgree(boolean agree) {
        this.agree = agree;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public boolean isAccepted() {
        return accepted;
    }

    public void setAccepted(boolean accepted) {
        this.accepted = accepted;
    }

    public PfUserVo getUserVo() {
        return userVo;
    }

    public void setUserVo(PfUserVo userVo) {
        this.userVo = userVo;
    }

}
